@@ -36,17 +36,7 @@ RSS parsing failed for %s
 
  . . . . 
 
-Click to create this page
-
-http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
-
-http://www.amazon.com/exec/obidos/ISBN=%s
-
-alternate
-
-http://www.pricescan.com/books/BookDetail.asp?isbn=%s
-
-search
+Click to edit this page
 
 Invalid action parameter %s
 
@@ -100,14 +90,14 @@ Include minor changes
 
 List later changes
 
+Filters
+
 Username:
 
 Host:
 
 Language:
 
-Filters
-
 Go!
 
 (minor)
@@ -318,6 +308,8 @@ This operation is restricted to site editors only...
 
 This operation is restricted to administrators only...
 
+Rule "%1" matched "%2" on this page.
+
 Index of all pages
 
 all pages
@@ -438,6 +430,8 @@ Too many connections by %s
 
 Please do not fetch more than %1 pages in %2 seconds.
 
+Check whether the web server can create the directory %s and whether it can create files in it.
+
 Recent Visitors
 
 Referrers
@@ -470,18 +464,26 @@ Delete page
 
 Rename this page to:
 
+Cannot highlight the language %s.
+
 Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
 
 The match parameter is missing.
 
 Page Collection for %s
 
+Previous
+
+Next
+
 Calendar %s
 
 Footnotes:
 
 image: %s
 
+Index
+
 Languages:
 
 Show!
@@ -506,8 +508,14 @@ None
 
 Type
 
+Permalink to "%s"
+
 Portrait
 
+Static Copy
+
+Alternatively, use one of the following templates:
+
 Thread: %s
 
 ID parameter is missing.
@@ -528,6 +536,24 @@ URL:
 
 Name:
 
+Failed to remove %s
+
+The translation is up to date.
+
+The translation is outdated.
+
+The page does not exist.
+
+http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
+
+http://www.amazon.com/exec/obidos/ISBN=%s
+
+alternate
+
+http://www.pricescan.com/books/BookDetail.asp?isbn=%s
+
+search
+
 Blog
 
 END_OF_TRANSLATION
