@@ -17,7 +17,7 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: sidebar.pl,v 1.3 2004/02/22 12:24:20 as Exp $</p>';
+$ModulesDescription .= '<p>sidebar.pl (proto)</p>';
 
 use vars qw($SidebarName);
 
@@ -28,6 +28,16 @@ $SidebarName = 'SideBar';
 *OldSideBarGetHeader = *GetHeader;
 *GetHeader = *NewSideBarGetHeader;
 
+$DefaultStyleSheet .= <<'EOT' unless $DefaultStyleSheet =~ /div\.sidebar/; # mod_perl?
+@media screen {
+  body { margin-right: 22ex; padding-right:1em; border-right: 1px solid #999; }
+  div.sidebar { position: absolute; right: 0; width: 20ex; top: 0; }
+}
+@media print {
+  div.sidebar { display: none; }
+}
+EOT
+
 # this assumes that *all* calls to GetHeader will print!
 sub NewSideBarGetHeader {
   my ($id) = @_;
